"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import preemo.gen.endpoints.batch_create_artifact_part_pb2
import preemo.gen.endpoints.batch_create_artifact_pb2
import preemo.gen.endpoints.batch_finalize_artifact_pb2
import preemo.gen.endpoints.batch_get_artifact_part_pb2
import preemo.gen.endpoints.batch_get_artifact_pb2
import preemo.gen.endpoints.check_function_pb2
import preemo.gen.endpoints.execute_function_pb2
import preemo.gen.endpoints.header_pb2
import preemo.gen.endpoints.register_function_pb2
import grpc

class WorkerServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    BatchCreateArtifact: grpc.UnaryUnaryMultiCallable[
        preemo.gen.endpoints.batch_create_artifact_pb2.BatchCreateArtifactRequest,
        preemo.gen.endpoints.batch_create_artifact_pb2.BatchCreateArtifactResponse,
    ]
    BatchCreateArtifactPart: grpc.UnaryUnaryMultiCallable[
        preemo.gen.endpoints.batch_create_artifact_part_pb2.BatchCreateArtifactPartRequest,
        preemo.gen.endpoints.batch_create_artifact_part_pb2.BatchCreateArtifactPartResponse,
    ]
    BatchFinalizeArtifact: grpc.UnaryUnaryMultiCallable[
        preemo.gen.endpoints.batch_finalize_artifact_pb2.BatchFinalizeArtifactRequest,
        preemo.gen.endpoints.batch_finalize_artifact_pb2.BatchFinalizeArtifactResponse,
    ]
    BatchGetArtifact: grpc.UnaryUnaryMultiCallable[
        preemo.gen.endpoints.batch_get_artifact_pb2.BatchGetArtifactRequest,
        preemo.gen.endpoints.batch_get_artifact_pb2.BatchGetArtifactResponse,
    ]
    BatchGetArtifactPart: grpc.UnaryUnaryMultiCallable[
        preemo.gen.endpoints.batch_get_artifact_part_pb2.BatchGetArtifactPartRequest,
        preemo.gen.endpoints.batch_get_artifact_part_pb2.BatchGetArtifactPartResponse,
    ]
    CheckFunction: grpc.UnaryUnaryMultiCallable[
        preemo.gen.endpoints.check_function_pb2.CheckFunctionRequest,
        preemo.gen.endpoints.check_function_pb2.CheckFunctionResponse,
    ]
    ExecuteFunction: grpc.UnaryUnaryMultiCallable[
        preemo.gen.endpoints.execute_function_pb2.ExecuteFunctionRequest,
        preemo.gen.endpoints.execute_function_pb2.ExecuteFunctionResponse,
    ]
    Initiate: grpc.UnaryUnaryMultiCallable[
        preemo.gen.endpoints.header_pb2.HeaderRequest,
        preemo.gen.endpoints.header_pb2.HeaderResponse,
    ]
    RegisterFunction: grpc.UnaryUnaryMultiCallable[
        preemo.gen.endpoints.register_function_pb2.RegisterFunctionRequest,
        preemo.gen.endpoints.register_function_pb2.RegisterFunctionResponse,
    ]

class WorkerServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def BatchCreateArtifact(
        self,
        request: preemo.gen.endpoints.batch_create_artifact_pb2.BatchCreateArtifactRequest,
        context: grpc.ServicerContext,
    ) -> preemo.gen.endpoints.batch_create_artifact_pb2.BatchCreateArtifactResponse: ...
    @abc.abstractmethod
    def BatchCreateArtifactPart(
        self,
        request: preemo.gen.endpoints.batch_create_artifact_part_pb2.BatchCreateArtifactPartRequest,
        context: grpc.ServicerContext,
    ) -> preemo.gen.endpoints.batch_create_artifact_part_pb2.BatchCreateArtifactPartResponse: ...
    @abc.abstractmethod
    def BatchFinalizeArtifact(
        self,
        request: preemo.gen.endpoints.batch_finalize_artifact_pb2.BatchFinalizeArtifactRequest,
        context: grpc.ServicerContext,
    ) -> preemo.gen.endpoints.batch_finalize_artifact_pb2.BatchFinalizeArtifactResponse: ...
    @abc.abstractmethod
    def BatchGetArtifact(
        self,
        request: preemo.gen.endpoints.batch_get_artifact_pb2.BatchGetArtifactRequest,
        context: grpc.ServicerContext,
    ) -> preemo.gen.endpoints.batch_get_artifact_pb2.BatchGetArtifactResponse: ...
    @abc.abstractmethod
    def BatchGetArtifactPart(
        self,
        request: preemo.gen.endpoints.batch_get_artifact_part_pb2.BatchGetArtifactPartRequest,
        context: grpc.ServicerContext,
    ) -> preemo.gen.endpoints.batch_get_artifact_part_pb2.BatchGetArtifactPartResponse: ...
    @abc.abstractmethod
    def CheckFunction(
        self,
        request: preemo.gen.endpoints.check_function_pb2.CheckFunctionRequest,
        context: grpc.ServicerContext,
    ) -> preemo.gen.endpoints.check_function_pb2.CheckFunctionResponse: ...
    @abc.abstractmethod
    def ExecuteFunction(
        self,
        request: preemo.gen.endpoints.execute_function_pb2.ExecuteFunctionRequest,
        context: grpc.ServicerContext,
    ) -> preemo.gen.endpoints.execute_function_pb2.ExecuteFunctionResponse: ...
    @abc.abstractmethod
    def Initiate(
        self,
        request: preemo.gen.endpoints.header_pb2.HeaderRequest,
        context: grpc.ServicerContext,
    ) -> preemo.gen.endpoints.header_pb2.HeaderResponse: ...
    @abc.abstractmethod
    def RegisterFunction(
        self,
        request: preemo.gen.endpoints.register_function_pb2.RegisterFunctionRequest,
        context: grpc.ServicerContext,
    ) -> preemo.gen.endpoints.register_function_pb2.RegisterFunctionResponse: ...

def add_WorkerServiceServicer_to_server(servicer: WorkerServiceServicer, server: grpc.Server) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from endpoints import batch_create_artifact_part_pb2 as endpoints_dot_batch__create__artifact__part__pb2
from endpoints import batch_create_artifact_pb2 as endpoints_dot_batch__create__artifact__pb2
from endpoints import batch_finalize_artifact_pb2 as endpoints_dot_batch__finalize__artifact__pb2
from endpoints import batch_get_artifact_part_pb2 as endpoints_dot_batch__get__artifact__part__pb2
from endpoints import batch_get_artifact_pb2 as endpoints_dot_batch__get__artifact__pb2
from endpoints import check_function_pb2 as endpoints_dot_check__function__pb2
from endpoints import execute_function_pb2 as endpoints_dot_execute__function__pb2
from endpoints import header_pb2 as endpoints_dot_header__pb2
from endpoints import register_function_pb2 as endpoints_dot_register__function__pb2


class WorkerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BatchCreateArtifact = channel.unary_unary(
                '/services.WorkerService/BatchCreateArtifact',
                request_serializer=endpoints_dot_batch__create__artifact__pb2.BatchCreateArtifactRequest.SerializeToString,
                response_deserializer=endpoints_dot_batch__create__artifact__pb2.BatchCreateArtifactResponse.FromString,
                )
        self.BatchCreateArtifactPart = channel.unary_unary(
                '/services.WorkerService/BatchCreateArtifactPart',
                request_serializer=endpoints_dot_batch__create__artifact__part__pb2.BatchCreateArtifactPartRequest.SerializeToString,
                response_deserializer=endpoints_dot_batch__create__artifact__part__pb2.BatchCreateArtifactPartResponse.FromString,
                )
        self.BatchFinalizeArtifact = channel.unary_unary(
                '/services.WorkerService/BatchFinalizeArtifact',
                request_serializer=endpoints_dot_batch__finalize__artifact__pb2.BatchFinalizeArtifactRequest.SerializeToString,
                response_deserializer=endpoints_dot_batch__finalize__artifact__pb2.BatchFinalizeArtifactResponse.FromString,
                )
        self.BatchGetArtifact = channel.unary_unary(
                '/services.WorkerService/BatchGetArtifact',
                request_serializer=endpoints_dot_batch__get__artifact__pb2.BatchGetArtifactRequest.SerializeToString,
                response_deserializer=endpoints_dot_batch__get__artifact__pb2.BatchGetArtifactResponse.FromString,
                )
        self.BatchGetArtifactPart = channel.unary_unary(
                '/services.WorkerService/BatchGetArtifactPart',
                request_serializer=endpoints_dot_batch__get__artifact__part__pb2.BatchGetArtifactPartRequest.SerializeToString,
                response_deserializer=endpoints_dot_batch__get__artifact__part__pb2.BatchGetArtifactPartResponse.FromString,
                )
        self.CheckFunction = channel.unary_unary(
                '/services.WorkerService/CheckFunction',
                request_serializer=endpoints_dot_check__function__pb2.CheckFunctionRequest.SerializeToString,
                response_deserializer=endpoints_dot_check__function__pb2.CheckFunctionResponse.FromString,
                )
        self.ExecuteFunction = channel.unary_unary(
                '/services.WorkerService/ExecuteFunction',
                request_serializer=endpoints_dot_execute__function__pb2.ExecuteFunctionRequest.SerializeToString,
                response_deserializer=endpoints_dot_execute__function__pb2.ExecuteFunctionResponse.FromString,
                )
        self.Initiate = channel.unary_unary(
                '/services.WorkerService/Initiate',
                request_serializer=endpoints_dot_header__pb2.HeaderRequest.SerializeToString,
                response_deserializer=endpoints_dot_header__pb2.HeaderResponse.FromString,
                )
        self.RegisterFunction = channel.unary_unary(
                '/services.WorkerService/RegisterFunction',
                request_serializer=endpoints_dot_register__function__pb2.RegisterFunctionRequest.SerializeToString,
                response_deserializer=endpoints_dot_register__function__pb2.RegisterFunctionResponse.FromString,
                )


class WorkerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BatchCreateArtifact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchCreateArtifactPart(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchFinalizeArtifact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetArtifact(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchGetArtifactPart(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckFunction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteFunction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Initiate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterFunction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BatchCreateArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchCreateArtifact,
                    request_deserializer=endpoints_dot_batch__create__artifact__pb2.BatchCreateArtifactRequest.FromString,
                    response_serializer=endpoints_dot_batch__create__artifact__pb2.BatchCreateArtifactResponse.SerializeToString,
            ),
            'BatchCreateArtifactPart': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchCreateArtifactPart,
                    request_deserializer=endpoints_dot_batch__create__artifact__part__pb2.BatchCreateArtifactPartRequest.FromString,
                    response_serializer=endpoints_dot_batch__create__artifact__part__pb2.BatchCreateArtifactPartResponse.SerializeToString,
            ),
            'BatchFinalizeArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchFinalizeArtifact,
                    request_deserializer=endpoints_dot_batch__finalize__artifact__pb2.BatchFinalizeArtifactRequest.FromString,
                    response_serializer=endpoints_dot_batch__finalize__artifact__pb2.BatchFinalizeArtifactResponse.SerializeToString,
            ),
            'BatchGetArtifact': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetArtifact,
                    request_deserializer=endpoints_dot_batch__get__artifact__pb2.BatchGetArtifactRequest.FromString,
                    response_serializer=endpoints_dot_batch__get__artifact__pb2.BatchGetArtifactResponse.SerializeToString,
            ),
            'BatchGetArtifactPart': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchGetArtifactPart,
                    request_deserializer=endpoints_dot_batch__get__artifact__part__pb2.BatchGetArtifactPartRequest.FromString,
                    response_serializer=endpoints_dot_batch__get__artifact__part__pb2.BatchGetArtifactPartResponse.SerializeToString,
            ),
            'CheckFunction': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckFunction,
                    request_deserializer=endpoints_dot_check__function__pb2.CheckFunctionRequest.FromString,
                    response_serializer=endpoints_dot_check__function__pb2.CheckFunctionResponse.SerializeToString,
            ),
            'ExecuteFunction': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteFunction,
                    request_deserializer=endpoints_dot_execute__function__pb2.ExecuteFunctionRequest.FromString,
                    response_serializer=endpoints_dot_execute__function__pb2.ExecuteFunctionResponse.SerializeToString,
            ),
            'Initiate': grpc.unary_unary_rpc_method_handler(
                    servicer.Initiate,
                    request_deserializer=endpoints_dot_header__pb2.HeaderRequest.FromString,
                    response_serializer=endpoints_dot_header__pb2.HeaderResponse.SerializeToString,
            ),
            'RegisterFunction': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterFunction,
                    request_deserializer=endpoints_dot_register__function__pb2.RegisterFunctionRequest.FromString,
                    response_serializer=endpoints_dot_register__function__pb2.RegisterFunctionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'services.WorkerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WorkerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BatchCreateArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/services.WorkerService/BatchCreateArtifact',
            endpoints_dot_batch__create__artifact__pb2.BatchCreateArtifactRequest.SerializeToString,
            endpoints_dot_batch__create__artifact__pb2.BatchCreateArtifactResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchCreateArtifactPart(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/services.WorkerService/BatchCreateArtifactPart',
            endpoints_dot_batch__create__artifact__part__pb2.BatchCreateArtifactPartRequest.SerializeToString,
            endpoints_dot_batch__create__artifact__part__pb2.BatchCreateArtifactPartResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchFinalizeArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/services.WorkerService/BatchFinalizeArtifact',
            endpoints_dot_batch__finalize__artifact__pb2.BatchFinalizeArtifactRequest.SerializeToString,
            endpoints_dot_batch__finalize__artifact__pb2.BatchFinalizeArtifactResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetArtifact(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/services.WorkerService/BatchGetArtifact',
            endpoints_dot_batch__get__artifact__pb2.BatchGetArtifactRequest.SerializeToString,
            endpoints_dot_batch__get__artifact__pb2.BatchGetArtifactResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BatchGetArtifactPart(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/services.WorkerService/BatchGetArtifactPart',
            endpoints_dot_batch__get__artifact__part__pb2.BatchGetArtifactPartRequest.SerializeToString,
            endpoints_dot_batch__get__artifact__part__pb2.BatchGetArtifactPartResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckFunction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/services.WorkerService/CheckFunction',
            endpoints_dot_check__function__pb2.CheckFunctionRequest.SerializeToString,
            endpoints_dot_check__function__pb2.CheckFunctionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteFunction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/services.WorkerService/ExecuteFunction',
            endpoints_dot_execute__function__pb2.ExecuteFunctionRequest.SerializeToString,
            endpoints_dot_execute__function__pb2.ExecuteFunctionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Initiate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/services.WorkerService/Initiate',
            endpoints_dot_header__pb2.HeaderRequest.SerializeToString,
            endpoints_dot_header__pb2.HeaderResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterFunction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/services.WorkerService/RegisterFunction',
            endpoints_dot_register__function__pb2.RegisterFunctionRequest.SerializeToString,
            endpoints_dot_register__function__pb2.RegisterFunctionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GetArtifactPartConfigMetadata(google.protobuf.message.Message):
    """This config is included for potential future use."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetArtifactPartConfigMetadata = GetArtifactPartConfigMetadata

@typing_extensions.final
class GetArtifactPartConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadatasByPartNumberEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___GetArtifactPartConfigMetadata: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___GetArtifactPartConfigMetadata | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    METADATAS_BY_PART_NUMBER_FIELD_NUMBER: builtins.int
    @property
    def metadatas_by_part_number(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___GetArtifactPartConfigMetadata]: ...
    def __init__(
        self,
        *,
        metadatas_by_part_number: collections.abc.Mapping[builtins.int, global___GetArtifactPartConfigMetadata] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadatas_by_part_number", b"metadatas_by_part_number"]) -> None: ...

global___GetArtifactPartConfig = GetArtifactPartConfig

@typing_extensions.final
class BatchGetArtifactPartRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConfigsByArtifactIdEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___GetArtifactPartConfig: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___GetArtifactPartConfig | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONFIGS_BY_ARTIFACT_ID_FIELD_NUMBER: builtins.int
    @property
    def configs_by_artifact_id(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___GetArtifactPartConfig]: ...
    def __init__(
        self,
        *,
        configs_by_artifact_id: collections.abc.Mapping[builtins.str, global___GetArtifactPartConfig] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["configs_by_artifact_id", b"configs_by_artifact_id"]) -> None: ...

global___BatchGetArtifactPartRequest = BatchGetArtifactPartRequest

@typing_extensions.final
class GetArtifactPartResultMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNLOAD_SIGNED_URL_FIELD_NUMBER: builtins.int
    download_signed_url: builtins.str
    def __init__(
        self,
        *,
        download_signed_url: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_download_signed_url", b"_download_signed_url", "download_signed_url", b"download_signed_url"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_download_signed_url", b"_download_signed_url", "download_signed_url", b"download_signed_url"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_download_signed_url", b"_download_signed_url"]) -> typing_extensions.Literal["download_signed_url"] | None: ...

global___GetArtifactPartResultMetadata = GetArtifactPartResultMetadata

@typing_extensions.final
class GetArtifactPartResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadatasByPartNumberEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___GetArtifactPartResultMetadata: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___GetArtifactPartResultMetadata | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    METADATAS_BY_PART_NUMBER_FIELD_NUMBER: builtins.int
    @property
    def metadatas_by_part_number(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___GetArtifactPartResultMetadata]: ...
    def __init__(
        self,
        *,
        metadatas_by_part_number: collections.abc.Mapping[builtins.int, global___GetArtifactPartResultMetadata] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadatas_by_part_number", b"metadatas_by_part_number"]) -> None: ...

global___GetArtifactPartResult = GetArtifactPartResult

@typing_extensions.final
class BatchGetArtifactPartResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ResultsByArtifactIdEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___GetArtifactPartResult: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___GetArtifactPartResult | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESULTS_BY_ARTIFACT_ID_FIELD_NUMBER: builtins.int
    @property
    def results_by_artifact_id(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___GetArtifactPartResult]: ...
    def __init__(
        self,
        *,
        results_by_artifact_id: collections.abc.Mapping[builtins.str, global___GetArtifactPartResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["results_by_artifact_id", b"results_by_artifact_id"]) -> None: ...

global___BatchGetArtifactPartResponse = BatchGetArtifactPartResponse



# Generated by bin/dev/generate_protos.sh.  DO NOT EDIT!

# protoc does not and will not generate relative imports for python.
# This workaround was copied from https://github.com/protocolbuffers/protobuf/issues/1491#issuecomment-429735834:
import os
import sys

sys.path.append(os.path.dirname(__file__))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: models/value.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12models/value.proto\x12\x06models\x1a\x1cgoogle/protobuf/struct.proto\"X\n\x05Value\x12\x30\n\nnull_value\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x15\n\x0b\x61rtifact_id\x18\x02 \x01(\tH\x00\x42\x06\n\x04kindb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.value_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VALUE._serialized_start=60
  _VALUE._serialized_end=148
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: endpoints/register_function.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from models import registered_function_pb2 as models_dot_registered__function__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!endpoints/register_function.proto\x12\tendpoints\x1a models/registered_function.proto\"q\n\x17RegisterFunctionRequest\x12=\n\x14\x66unction_to_register\x18\x01 \x01(\x0b\x32\x1a.models.RegisteredFunctionH\x00\x88\x01\x01\x42\x17\n\x15_function_to_register\"\x1a\n\x18RegisterFunctionResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'endpoints.register_function_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGISTERFUNCTIONREQUEST._serialized_start=82
  _REGISTERFUNCTIONREQUEST._serialized_end=195
  _REGISTERFUNCTIONRESPONSE._serialized_start=197
  _REGISTERFUNCTIONRESPONSE._serialized_end=223
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: endpoints/batch_finalize_artifact.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'endpoints/batch_finalize_artifact.proto\x12\tendpoints\"\x18\n\x16\x46inalizeArtifactConfig\"\xdf\x01\n\x1c\x42\x61tchFinalizeArtifactRequest\x12`\n\x16\x63onfigs_by_artifact_id\x18\x01 \x03(\x0b\x32@.endpoints.BatchFinalizeArtifactRequest.ConfigsByArtifactIdEntry\x1a]\n\x18\x43onfigsByArtifactIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.endpoints.FinalizeArtifactConfig:\x02\x38\x01\"\x18\n\x16\x46inalizeArtifactResult\"\xe1\x01\n\x1d\x42\x61tchFinalizeArtifactResponse\x12\x61\n\x16results_by_artifact_id\x18\x01 \x03(\x0b\x32\x41.endpoints.BatchFinalizeArtifactResponse.ResultsByArtifactIdEntry\x1a]\n\x18ResultsByArtifactIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.endpoints.FinalizeArtifactResult:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'endpoints.batch_finalize_artifact_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BATCHFINALIZEARTIFACTREQUEST_CONFIGSBYARTIFACTIDENTRY._options = None
  _BATCHFINALIZEARTIFACTREQUEST_CONFIGSBYARTIFACTIDENTRY._serialized_options = b'8\001'
  _BATCHFINALIZEARTIFACTRESPONSE_RESULTSBYARTIFACTIDENTRY._options = None
  _BATCHFINALIZEARTIFACTRESPONSE_RESULTSBYARTIFACTIDENTRY._serialized_options = b'8\001'
  _FINALIZEARTIFACTCONFIG._serialized_start=54
  _FINALIZEARTIFACTCONFIG._serialized_end=78
  _BATCHFINALIZEARTIFACTREQUEST._serialized_start=81
  _BATCHFINALIZEARTIFACTREQUEST._serialized_end=304
  _BATCHFINALIZEARTIFACTREQUEST_CONFIGSBYARTIFACTIDENTRY._serialized_start=211
  _BATCHFINALIZEARTIFACTREQUEST_CONFIGSBYARTIFACTIDENTRY._serialized_end=304
  _FINALIZEARTIFACTRESULT._serialized_start=306
  _FINALIZEARTIFACTRESULT._serialized_end=330
  _BATCHFINALIZEARTIFACTRESPONSE._serialized_start=333
  _BATCHFINALIZEARTIFACTRESPONSE._serialized_end=558
  _BATCHFINALIZEARTIFACTRESPONSE_RESULTSBYARTIFACTIDENTRY._serialized_start=465
  _BATCHFINALIZEARTIFACTRESPONSE_RESULTSBYARTIFACTIDENTRY._serialized_end=558
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: models/registered_function.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n models/registered_function.proto\x12\x06models\"V\n\x12RegisteredFunction\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tnamespace\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_namespaceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'models.registered_function_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGISTEREDFUNCTION._serialized_start=44
  _REGISTEREDFUNCTION._serialized_end=130
# @@protoc_insertion_point(module_scope)



from typing import Protocol, runtime_checkable

import grpc

from preemo import __version__
from preemo.gen.endpoints.batch_create_artifact_part_pb2 import (
    BatchCreateArtifactPartRequest,
    BatchCreateArtifactPartResponse,
)
from preemo.gen.endpoints.batch_create_artifact_pb2 import (
    BatchCreateArtifactRequest,
    BatchCreateArtifactResponse,
)
from preemo.gen.endpoints.batch_finalize_artifact_pb2 import (
    BatchFinalizeArtifactRequest,
    BatchFinalizeArtifactResponse,
)
from preemo.gen.endpoints.batch_get_artifact_part_pb2 import (
    BatchGetArtifactPartRequest,
    BatchGetArtifactPartResponse,
)
from preemo.gen.endpoints.batch_get_artifact_pb2 import (
    BatchGetArtifactRequest,
    BatchGetArtifactResponse,
)
from preemo.gen.endpoints.check_function_pb2 import (
    CheckFunctionRequest,
    CheckFunctionResponse,
)
from preemo.gen.endpoints.execute_function_pb2 import (
    ExecuteFunctionRequest,
    ExecuteFunctionResponse,
)
from preemo.gen.endpoints.header_pb2 import HeaderRequest, HeaderResponse
from preemo.gen.endpoints.register_function_pb2 import (
    RegisterFunctionRequest,
    RegisterFunctionResponse,
)
from preemo.gen.services.worker_pb2_grpc import WorkerServiceStub
from preemo.worker._validation import ensure_keys_match


@runtime_checkable
class IMessagingClient(Protocol):
    def batch_create_artifact(
        self, request: BatchCreateArtifactRequest
    ) -> BatchCreateArtifactResponse:
        pass

    def batch_create_artifact_part(
        self, request: BatchCreateArtifactPartRequest
    ) -> BatchCreateArtifactPartResponse:
        pass

    def batch_finalize_artifact(
        self, request: BatchFinalizeArtifactRequest
    ) -> BatchFinalizeArtifactResponse:
        pass

    def batch_get_artifact(
        self, request: BatchGetArtifactRequest
    ) -> BatchGetArtifactResponse:
        pass

    def batch_get_artifact_part(
        self, request: BatchGetArtifactPartRequest
    ) -> BatchGetArtifactPartResponse:
        pass

    def check_function(self, request: CheckFunctionRequest) -> CheckFunctionResponse:
        pass

    def execute_function(
        self, request: ExecuteFunctionRequest
    ) -> ExecuteFunctionResponse:
        pass

    def register_function(
        self, request: RegisterFunctionRequest
    ) -> RegisterFunctionResponse:
        pass


class MessagingClient:
    def __init__(self, *, worker_server_url: str) -> None:
        # TODO(adrian@preemo.io, 03/25/2023): investigate whether it makes sense to use secure_channel instead
        self._channel = grpc.insecure_channel(target=worker_server_url)
        self._worker_service = WorkerServiceStub(self._channel)

        self._initiate(HeaderRequest(version=__version__))

    def _initiate(self, request: HeaderRequest) -> HeaderResponse:
        return self._worker_service.Initiate(request)

    def batch_create_artifact(
        self, request: BatchCreateArtifactRequest
    ) -> BatchCreateArtifactResponse:
        response = self._worker_service.BatchCreateArtifact(request)
        ensure_keys_match(
            expected=request.configs_by_index, actual=response.results_by_index
        )

        return response

    def batch_create_artifact_part(
        self, request: BatchCreateArtifactPartRequest
    ) -> BatchCreateArtifactPartResponse:
        response = self._worker_service.BatchCreateArtifactPart(request)
        ensure_keys_match(
            expected=request.configs_by_artifact_id,
            actual=response.results_by_artifact_id,
        )

        return response

    def batch_finalize_artifact(
        self, request: BatchFinalizeArtifactRequest
    ) -> BatchFinalizeArtifactResponse:
        response = self._worker_service.BatchFinalizeArtifact(request)
        ensure_keys_match(
            expected=request.configs_by_artifact_id,
            actual=response.results_by_artifact_id,
        )

        return response

    def batch_get_artifact(
        self, request: BatchGetArtifactRequest
    ) -> BatchGetArtifactResponse:
        response = self._worker_service.BatchGetArtifact(request)
        ensure_keys_match(
            expected=request.configs_by_artifact_id,
            actual=response.results_by_artifact_id,
        )

        return response

    def batch_get_artifact_part(
        self, request: BatchGetArtifactPartRequest
    ) -> BatchGetArtifactPartResponse:
        response = self._worker_service.BatchGetArtifactPart(request)
        ensure_keys_match(
            expected=request.configs_by_artifact_id,
            actual=response.results_by_artifact_id,
        )

        return response

    def check_function(self, request: CheckFunctionRequest) -> CheckFunctionResponse:
        return self._worker_service.CheckFunction(request)

    def execute_function(
        self, request: ExecuteFunctionRequest
    ) -> ExecuteFunctionResponse:
        response = self._worker_service.ExecuteFunction(request)
        ensure_keys_match(
            expected=request.parameters_by_index,
            actual=response.results_by_index,
        )

        return response

    def register_function(
        self, request: RegisterFunctionRequest
    ) -> RegisterFunctionResponse:
        return self._worker_service.RegisterFunction(request)


# This class is intended to be used for tests and local development
class LocalMessagingClient:
    def batch_create_artifact(
        self, request: BatchCreateArtifactRequest
    ) -> BatchCreateArtifactResponse:
        print(f"sending batch create artifact request: {request}")
        return BatchCreateArtifactResponse()

    def batch_create_artifact_part(
        self, request: BatchCreateArtifactPartRequest
    ) -> BatchCreateArtifactPartResponse:
        print(f"sending batch create artifact part request: {request}")
        return BatchCreateArtifactPartResponse()

    def batch_finalize_artifact(
        self, request: BatchFinalizeArtifactRequest
    ) -> BatchFinalizeArtifactResponse:
        print(f"sending batch finalize artifact request: {request}")
        return BatchFinalizeArtifactResponse()

    def batch_get_artifact(
        self, request: BatchGetArtifactRequest
    ) -> BatchGetArtifactResponse:
        print(f"sending batch get artifact request: {request}")
        return BatchGetArtifactResponse()

    def batch_get_artifact_part(
        self, request: BatchGetArtifactPartRequest
    ) -> BatchGetArtifactPartResponse:
        print(f"sending batch get artifact part request: {request}")
        return BatchGetArtifactPartResponse()

    def check_function(self, request: CheckFunctionRequest) -> CheckFunctionResponse:
        print(f"sending check function request: {request}")
        return CheckFunctionResponse()

    def execute_function(
        self, request: ExecuteFunctionRequest
    ) -> ExecuteFunctionResponse:
        print(f"sending execute function request: {request}")
        return ExecuteFunctionResponse()

    def register_function(
        self, request: RegisterFunctionRequest
    ) -> RegisterFunctionResponse:
        print(f"sending register function request: {request}")
        return RegisterFunctionResponse()



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RegisteredFunction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Required field that should be unique within the namespace."""
    namespace: builtins.str
    """Optional field that defaults to a global namespace if unspecified."""
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        namespace: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_name", b"_name", "_namespace", b"_namespace", "name", b"name", "namespace", b"namespace"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_name", b"_name", "_namespace", b"_namespace", "name", b"name", "namespace", b"namespace"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_name", b"_name"]) -> typing_extensions.Literal["name"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_namespace", b"_namespace"]) -> typing_extensions.Literal["namespace"] | None: ...

global___RegisteredFunction = RegisteredFunction



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: endpoints/batch_get_artifact.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"endpoints/batch_get_artifact.proto\x12\tendpoints\"\x13\n\x11GetArtifactConfig\"\xd0\x01\n\x17\x42\x61tchGetArtifactRequest\x12[\n\x16\x63onfigs_by_artifact_id\x18\x01 \x03(\x0b\x32;.endpoints.BatchGetArtifactRequest.ConfigsByArtifactIdEntry\x1aX\n\x18\x43onfigsByArtifactIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.endpoints.GetArtifactConfig:\x02\x38\x01\";\n\x11GetArtifactResult\x12\x17\n\npart_count\x18\x01 \x01(\rH\x00\x88\x01\x01\x42\r\n\x0b_part_count\"\xd2\x01\n\x18\x42\x61tchGetArtifactResponse\x12\\\n\x16results_by_artifact_id\x18\x01 \x03(\x0b\x32<.endpoints.BatchGetArtifactResponse.ResultsByArtifactIdEntry\x1aX\n\x18ResultsByArtifactIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.endpoints.GetArtifactResult:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'endpoints.batch_get_artifact_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BATCHGETARTIFACTREQUEST_CONFIGSBYARTIFACTIDENTRY._options = None
  _BATCHGETARTIFACTREQUEST_CONFIGSBYARTIFACTIDENTRY._serialized_options = b'8\001'
  _BATCHGETARTIFACTRESPONSE_RESULTSBYARTIFACTIDENTRY._options = None
  _BATCHGETARTIFACTRESPONSE_RESULTSBYARTIFACTIDENTRY._serialized_options = b'8\001'
  _GETARTIFACTCONFIG._serialized_start=49
  _GETARTIFACTCONFIG._serialized_end=68
  _BATCHGETARTIFACTREQUEST._serialized_start=71
  _BATCHGETARTIFACTREQUEST._serialized_end=279
  _BATCHGETARTIFACTREQUEST_CONFIGSBYARTIFACTIDENTRY._serialized_start=191
  _BATCHGETARTIFACTREQUEST_CONFIGSBYARTIFACTIDENTRY._serialized_end=279
  _GETARTIFACTRESULT._serialized_start=281
  _GETARTIFACTRESULT._serialized_end=340
  _BATCHGETARTIFACTRESPONSE._serialized_start=343
  _BATCHGETARTIFACTRESPONSE._serialized_end=553
  _BATCHGETARTIFACTRESPONSE_RESULTSBYARTIFACTIDENTRY._serialized_start=465
  _BATCHGETARTIFACTRESPONSE_RESULTSBYARTIFACTIDENTRY._serialized_end=553
# @@protoc_insertion_point(module_scope)



from typing import Mapping


def ensure_keys_match(*, expected: Mapping, actual: Mapping) -> None:
    if expected.keys() == actual.keys():
        return

    message = "expected keys to match but found:"

    missing_keys = expected.keys() - actual.keys()
    if len(missing_keys) > 0:
        message += f"\nmissing expected keys: {missing_keys}"

    unexpected_keys = actual.keys() - expected.keys()
    if len(unexpected_keys) > 0:
        message += f"\nunexpected keys: {unexpected_keys}"

    raise Exception(message)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import preemo.gen.models.registered_function_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RegisterFunctionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_TO_REGISTER_FIELD_NUMBER: builtins.int
    @property
    def function_to_register(self) -> preemo.gen.models.registered_function_pb2.RegisteredFunction: ...
    def __init__(
        self,
        *,
        function_to_register: preemo.gen.models.registered_function_pb2.RegisteredFunction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_function_to_register", b"_function_to_register", "function_to_register", b"function_to_register"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_function_to_register", b"_function_to_register", "function_to_register", b"function_to_register"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_function_to_register", b"_function_to_register"]) -> typing_extensions.Literal["function_to_register"] | None: ...

global___RegisterFunctionRequest = RegisterFunctionRequest

@typing_extensions.final
class RegisterFunctionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterFunctionResponse = RegisterFunctionResponse
